[Libreoffice-commits] core.git: sw/source

Caolán McNamara caolanm at redhat.com
Wed Sep 2 09:03:37 PDT 2015


 sw/source/filter/ww8/ww8scan.cxx |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit cf5f20b3ddfe87162c7701aa1523b1a6ab4a90b8
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Wed Sep 2 17:01:01 2015 +0100

    hinter: 'after' better than 'behind'
    
    "'Behind' is typically used when the context has meanings of depth, and as such
    becomes ambiguous when used in a flat list ... 'After'/'before' contain
    meanings of ordering which are unambiguous"
    
    Change-Id: I1b59c7e3fe5773b88e8e7b9a01cefb28e4851090

diff --git a/sw/source/filter/ww8/ww8scan.cxx b/sw/source/filter/ww8/ww8scan.cxx
index 07b1dd6..ed6431a 100644
--- a/sw/source/filter/ww8/ww8scan.cxx
+++ b/sw/source/filter/ww8/ww8scan.cxx
@@ -4346,7 +4346,7 @@ bool WW8PLCFx_AtnBook::getIsEnd() const
 
 #ifndef DUMP
 
 // In the end of an paragraph in WW6 the attribute extends behind the <CR>.
 // This will be reset by one character to be used with SW,
 // if we don't expect trouble thereby.
 void WW8PLCFMan::AdjustEnds( WW8PLCFxDesc& rDesc )
@@ -4370,7 +4370,7 @@ void WW8PLCFMan::AdjustEnds( WW8PLCFxDesc& rDesc )
     {
         if ( pPap->nEndPos != WW8_CP_MAX )    // Para adjust
         {
-            nLineEnd = pPap->nEndPos;// nLineEnd points *behind* the <CR>
+            nLineEnd = pPap->nEndPos;// nLineEnd points *after* the <CR>
             pPap->nEndPos--;        // shorten paragraph end by one character
 
             // Is there already a sep end, which points to the current paragraph end?
@@ -4346,7 +4346,7 @@ bool WW8PLCFx_AtnBook::getIsEnd() const
 #ifndef DUMP
 
-// In the end of an paragraph in WW6 the attribute extends behind the <CR>.
+// In the end of an paragraph in WW6 the attribute extends after the <CR>.
 // This will be reset by one character to be used with SW,
 // if we don't expect trouble thereby.


More information about the Libreoffice-commits mailing list